/* ***** BEGIN LICENSE BLOCK *****
 *   Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is ThumbsDown.
 *
 * The Initial Developer of the Original Code is
 * Atte Kemppilä.
 * Portions created by the Initial Developer are Copyright (C) 2008
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 * 
 * ***** END LICENSE BLOCK ***** */


function WrappedPage() // extend WizardPage
{
    var depends = "images script";
    WizardPage.call(this, depends);
    
    this.value.parent = this;
}

WrappedPage.prototype =
{
    get name() { return $("mlist_wrapped_name"); },
    
    value:
    {
        parent: null,
        get alt()      { return $("tbox_wrapped_value_alt"); },
        get id()       { return $("tbox_wrapped_value_id"); },
        get src()      { return $("tbox_wrapped_value_src"); },
        get selected() { return this[this.parent.name.value]; } 
    },
    
    onPageShow: function()
    {
        var names = ["alt", "id", "src"];
        
        // populate listboxes
        if (this.dirty.images)
        {
            for each (var name in names)
            {
                var rlbox = $("rlbox_wrapped_values_" + name);
                while (rlbox.itemCount > 0)
                    rlbox.removeItemAt(0);
                for each (var thumbnail in model.images)
                    rlbox.appendItem(thumbnail.target.image[name]);
            }
        }
        
        if (this.dirty.images || this.dirty.script)
        {
            var values =
            {
                alt: scriptWizard.getWrappedAttributeRegExp(model.images, "alt"),
                id:  scriptWizard.getWrappedAttributeRegExp(model.images, "id"),
                src: scriptWizard.getWrappedUrlAttributeRegExp(model.images, "url"),
            }
            
            // default to 'id' if it exists and is not a regexp
            this.name.value = ((values.id && /^\w+$/.test(values.id)) ? "id" : "src");
            
            for each (var name in names)
            {
                $("mitem_wrapped_name_" + name).disabled = (! values[name]);
                this.value[name].defaultValue = (values[name] ? values[name] : "");
            }
            
            var script = model.script;
            if (script && (script.type == TYPE_WRAPPED) && values[script.attrName])
            {
                this.name.value = script.attrName;
                this.value.selected.defaultValue = script.attrValue;
            }
            
            for each (var name in names)
                this.value[name].reset();
        }
        
        if (this.dirty.page)
        {
            this._updateButtons();
            this._updateValue();
            this._updateName();
        }
    },
    
    onNameSelect: function()
    {
        this._updateName();
        this._updateValue();
    },
    
    onValueInput: function()
    {
        if (this.value.updateTimer)
            this.value.updateTimer.cancel();
        
        this.value.updateTimer = callLater(INPUT_DELAY, this, this._updateValue);
        
        this._updateButtons();
        wizard.updateWizardButtons();
    },
    
    resetValue: function()
    {
        this.value.selected.reset();
        this._updateValue();
        this._updateButtons();
        wizard.updateWizardButtons();
    },
    
    canAdvance: function()
    {
        if (this.value.updateTimer)
            return false;
        
        return $("rlbox_wrapped_values_" + this.name.value).match;
    },
    
    _updateName: function()
    {
        $("deck_wrapped_value").selectedIndex = this.name.selectedIndex;
        $("deck_wrapped_values").selectedIndex = this.name.selectedIndex;
    },
    
    _updateValue: function()
    {
        if (this.value.updateTimer)
        {
            this.value.updateTimer.cancel();
            delete this.value.updateTimer;
        }
        
        if (page != pages.wrapped)
            return;
        
        var value = "^" + this.value.selected.value + "$";
        $("rlbox_wrapped_values_" + this.name.value).pattern = value;
        
        wizard.updateWizardButtons();
    },
    
    _updateButtons: function()
    {
        $("btn_wrapped_value_reset").disabled = (this.value.selected.value == this.value.selected.defaultValue);
    },
    
    onPageAdvanced: function()
    {
        model.type = TYPE_WRAPPED;
        model.attrName = this.name.value;
        model.attrValue = this.value.selected.value;
        return wizard.advance("script");
    }
}

extend(WrappedPage, WizardPage);

pages.wrapped = new WrappedPage();
